@@ -1,28 +1,29 @@
-$('document').ready(function(){
+$('document').ready(function () {
     let tableList = {}
-    $(".data-table").each(function(){
+    $(".data-table").each(function () {
         const tableSelector = $(this);
         const tableId = tableSelector.data('id');
-        tableList[tableId] = {'visible': false,'table': null};
+        tableList[tableId] = { 'visible': false, 'table': null };
     });
 
-    setInterval(function(){
+    setInterval(function () {
         $(".data-table")
-            .each(function(){ // Remove tables that is hidden
+            .each(function () { // Remove tables that is hidden
                 const tableSelector = $(this);
                 const newId = tableSelector.data('id');
                 const tableEntry = tableList[newId];
-                if(!tableSelector.is(':visible') && tableEntry.visible){
+                if (!tableSelector.is(':visible') && tableEntry.visible) {
                     tableEntry.visible = false;
                     tableEntry.table && tableEntry.table.destroy();
                     $('.datatable-filters.' + newId + ' #DataTables_Table_0_filter').remove();
-                }})
-            .each(function(index){ // Add tables that is visible
+                }
+            })
+            .each(function (index) { // Add tables that is visible
                 const tableSelector = $(this);
                 const tableElement = tableSelector[0];
                 const newId = tableSelector.data('id');
                 const tableEntry = tableList[newId];
-                if(tableSelector.is(':visible') && !tableEntry.visible){
+                if (tableSelector.is(':visible') && !tableEntry.visible) {
                     tableEntry.visible = true;
                     tableEntry.table = datatableify(tableElement, index);
                 }
@@ -37,7 +38,7 @@ function getContextFromUrl() {
         urlFragment: urlFragment,
         matchedGroups: [...urlFragment.matchAll(/table([\d]){(.*?)}/g)]
             .reduce((acc, elem) => {
-                return {...acc, [elem[1]]: elem[2]}
+                return { ...acc, [elem[1]]: elem[2] }
             }, {})
     }
 }
@@ -51,15 +52,15 @@ function buildUrlFragment(index, d) {
         `&order_dir=${d['order'][0]['dir']}` : ''
 
     const context = getContextFromUrl();
-    const contextData = `page=${page}${order}`+
+    const contextData = `page=${page}${order}` +
         (search ? `&search=${search}` : '') +
         (filters ? `&filter[]=${filters}` : '')
 
     let newUrlFragment = ""
-    if(index in context.matchedGroups){
+    if (index in context.matchedGroups) {
         newUrlFragment = context.urlFragment.replace(context.matchedGroups[index], contextData);
     }
-    else if (context.urlFragment !== ""){
+    else if (context.urlFragment !== "") {
         newUrlFragment = context.urlFragment + `&table${index}{${contextData}}`;
     }
     else {
@@ -70,13 +71,13 @@ function buildUrlFragment(index, d) {
 
 function parseUrlFragment(index) {
     const context = getContextFromUrl();
-    if(index in context.matchedGroups){
+    if (index in context.matchedGroups) {
         return context.matchedGroups[index]
             .split('&')
             .map((elem) => elem.split('='))
             .reduce((acc, value) => {
                 if (value.length === 2) { // Handle "xxx=yyy"
-                    return {...acc, [value[0]]: value[1]}
+                    return { ...acc, [value[0]]: value[1] }
                 } else if (value.length === 3) { // Handle "xxx[]=yyy=zzz"
                     const key = value[0].slice(0, -2);
                     (acc[key] = acc[key] || []).push(`${value[1]}=${value[2]}`);
@@ -98,23 +99,22 @@ function datatableify(table, index) {
     let order_history = null;
 
     const history_state = parseUrlFragment(index);
-    if(!jQuery.isEmptyObject(history_state))
-    {
+    if (!jQuery.isEmptyObject(history_state)) {
         page_index = history_state.page;
         search_history = history_state.search || null;
-        if(history_state.order_col && history_state.order_dir){
+        if (history_state.order_col && history_state.order_dir) {
             order_history = [{
                 'column': history_state.order_col,
                 'dir': history_state.order_dir
             }]
         }
-        if(history_state.filter){
+        if (history_state.filter) {
             $(".datatable-filters." + id + " input:checkbox.datatable-filter").each(function () {
-                if(history_state.filter.indexOf(this.name) > -1) {
+                if (history_state.filter.indexOf(this.name) > -1) {
                     $(this).attr('checked', true)
                     let group = $(this).data('group');
-                    if(group){
-                        $('#'+group).prop('checked', true);
+                    if (group) {
+                        $('#' + group).prop('checked', true);
                     }
                 }
             })
@@ -146,10 +146,10 @@ function datatableify(table, index) {
         ajax: {
             url: "?format=json",
             data: d => {
-                if (search_history !== null){
+                if (search_history !== null) {
                     d['search']['value'] = search_history;
                 }
-                if (order_history !== null){
+                if (order_history !== null) {
                     d['order'] = order_history
                     order_history = null;
                 }
@@ -165,10 +165,10 @@ function datatableify(table, index) {
                         d["filters"].push(param)
                     }
                 });
-                $(".datatable-filters."+id+" input:checkbox:checked.datatable-filter").each(function() {
+                $(".datatable-filters." + id + " input:checkbox:checked.datatable-filter").each(function () {
                     d["filters"].push(this.name);
                 });
-                $(".datatable-filters."+id+" input:radio:checked.datatable-filter").each(function() {
+                $(".datatable-filters." + id + " input:radio:checked.datatable-filter").each(function () {
                     d["select"] = this.value
                 });
                 d["visible"] = [];
@@ -179,7 +179,7 @@ function datatableify(table, index) {
                 history.replaceState(null, '', buildUrlFragment(index, d))
             },
         },
-        createdRow: function(row, data, dataIndex) {
+        createdRow: function (row, data, dataIndex) {
             $(row).addClass("table__row");
             $(row).addClass(data.html_class);
         },
@@ -190,14 +190,14 @@ function datatableify(table, index) {
     var table = datatable.DataTable(settings);
 
     const date_filter_selector = $('.datatable-filter-date')
-    date_filter_selector.each(function() {
+    date_filter_selector.each(function () {
         new DateTime($(this), {
-            format: 'yyyy-MM-dd HH:mm',
+            format: 'yyyy-MM-DD HH:mm',
             buttons: { clear: true },
             locale: settings.language.dateTimePickerLocale || 'en',
             i18n: settings.language.dateTimePicker || {}
         });
-        $(this).on('change', function(){
+        $(this).on('change', function () {
             const name = $(this).attr('name')
             const val = $(this).val();
             $(this).attr('param', name + '=' + val)
@@ -205,17 +205,17 @@ function datatableify(table, index) {
         });
     })
 
-    $('.datatable-filter.'+id).on('change', function(){
-        var className = 'input:checkbox:checked.'+this.className.split(" ").join('.');
+    $('.datatable-filter.' + id).on('change', function () {
+        var className = 'input:checkbox:checked.' + this.className.split(" ").join('.');
         var checked = $(className);
         var group = $(this).data('group');
         if (group) {
-            $('#'+group).prop('checked', checked.length> 0);
+            $('#' + group).prop('checked', checked.length > 0);
         }
         table.draw();
     });
 
-    $('.datatable-filter-group.' + id).on('change', function(){
+    $('.datatable-filter-group.' + id).on('change', function () {
         var group = this.id;
         $('.datatable-filter.' + group + '.' + id).prop('checked', this.checked);
         table.draw();
@@ -230,12 +230,12 @@ function datatableify(table, index) {
             table.draw();
         });
     }
-    if(search_history !== null){
+    if (search_history !== null) {
         table.search(search_history)
         search_history = null;
     }
 
-    $('.csv-button.'+id).click(function(e){
+    $('.csv-button.' + id).on('click', function (e) {
         var params = table.ajax.params();
         var href = "?format=csv&" + $.param(params);
         $(this).attr("href", href);
